---
title: <span class="badge object-type-scalar"></span> HexadecimalOx
---
# <span class="badge object-type-scalar"></span> HexadecimalOx

Hexadecimal (0x)

## Definition

```python
# Hexadecimal (0x)
HexadecimalOx: typing.Literal["hex0x"] = "hex0x"
```
